@@ -58,7 +58,7 @@
 #include "Configuration.h"
 #include "Control.h"
 
-static Lum::AppInfo info;
+static Lum::Def::AppInfo info;
 
 typedef Lum::Model::StdRefTable<Hiscore::Entry,std::vector<Hiscore::Entry> > HiscoreEntriesModel;
 typedef Lum::Base::Reference<HiscoreEntriesModel>                            HiscoreEntriesModelRef;
